@@ -506,6 +506,7 @@ class Witter():
     	if (self.gettingTweets == True):
     		#already in this method in a refresh
             print "a thread is already getting tweets"
+            self.showBusy(-1)
             return
     	self.gettingTweets = True
         print "getting tweets"
@@ -821,6 +822,7 @@ class Witter():
         #see if we have just an empty string (eg eroneous button press)
         if (searchterm == ""):
             print "nothing to search"
+            self.showBusy(-1)
             return
 
 
@@ -1094,6 +1096,7 @@ class Witter():
         tweet = self.builder.get_object("TweetText").get_text()
         #see if we have just an empty string (eg eroneous button press)
         if (tweet == ""):
+            self.showBusy(-1)
             return
         if (self.access_token != ""):
             print "using oauth"
@@ -1203,31 +1206,46 @@ class Witter():
 
 
     def get_specific_tweet(self, screen_name, tweet_id):
-        #this method gets an identified tweet from id and screenname
-        #Now for the main logic...fetching tweets
-        #at the moment I'm just using basic auth. 
-        #urllib2 provides all the HTTP handling stuff
-        auth_handler = urllib2.HTTPBasicAuthHandler()
-        #realm here is important. or at least it seemed to be
-        #this info is on the login box if you go to the url in a browser
-        auth_handler.add_password(realm='Twitter API',
-                          uri='http://twitter.com/statuses/show/' + str(tweet_id) + 'L.json',
-                          user=self.username,
-                          passwd=self.password)
-        #we create an 'opener' object with our auth_handler
-        opener = urllib2.build_opener(auth_handler)
-        # ...and install it globally so it can be used with urlopen.
-        urllib2.install_opener(opener)
-
         try:
+            #if we have an access token, use oauth
+            if (self.access_token != ""):
+                print "using oauth to get specific tweets"
+                twitter = oauthtwitter.OAuthApi(self.CONSUMER_KEY, self.CONSUMER_SECRET, self.access_token)
+                if (self.user == ""):
+                    self.user = twitter.GetUserInfo()
 
-            json = urllib2.urlopen('http://twitter.com/statuses/show/' + str(tweet_id) + 'L.json')
+                data = twitter.GetStatus(tweet_id)
 
-            #JSON is awesome stuff. we get given a long string of json encoded information
-            #which contains all the tweets, with lots of info, we decode to a json object
-            data = simplejson.loads(json.read())
-            return data['text']
+                return data.text
+
+
+            else:
+                #this method gets an identified tweet from id and screenname
+                #Now for the main logic...fetching tweets
+                #at the moment I'm just using basic auth. 
+                #urllib2 provides all the HTTP handling stuff
+                auth_handler = urllib2.HTTPBasicAuthHandler()
+                #realm here is important. or at least it seemed to be
+                #this info is on the login box if you go to the url in a browser
+                auth_handler.add_password(realm='Twitter API',
+                                  uri='http://twitter.com/statuses/show/' + str(tweet_id) + 'L.json',
+                                  user=self.username,
+                                  passwd=self.password)
+                #we create an 'opener' object with our auth_handler
+                opener = urllib2.build_opener(auth_handler)
+                # ...and install it globally so it can be used with urlopen.
+                urllib2.install_opener(opener)
+
+
+
+                json = urllib2.urlopen('http://twitter.com/statuses/show/' + str(tweet_id) + 'L.json')
+
+                #JSON is awesome stuff. we get given a long string of json encoded information
+                #which contains all the tweets, with lots of info, we decode to a json object
+                data = simplejson.loads(json.read())
+                return data['text']
         except IOError, e:
+            print e
             return "protected tweet"
 
 
